@@ -1,11 +1,13 @@
 from __future__ import annotations
 
+import re
+
+from collections.abc import Mapping
+from contextlib import suppress
 from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
-from typing import Dict
-from typing import Mapping
-from typing import Union
+from typing import ClassVar
 
 from cleo.helpers import option
 from packaging.utils import canonicalize_name
@@ -14,16 +16,18 @@ from tomlkit import inline_table
 from poetry.console.commands.command import Command
 from poetry.console.commands.env_command import EnvCommand
 from poetry.utils.dependency_specification import RequirementsParser
+from poetry.utils.env.python import Python
 
 
 if TYPE_CHECKING:
+    from cleo.io.inputs.option import Option
     from packaging.utils import NormalizedName
     from poetry.core.packages.package import Package
     from tomlkit.items import InlineTable
 
     from poetry.repositories import RepositoryPool
 
-Requirements = Dict[str, Union[str, Mapping[str, Any]]]
+Requirements = dict[str, str | Mapping[str, Any]]
 
 
 class InitCommand(Command):
@@ -32,7 +36,7 @@ class InitCommand(Command):
         "Creates a basic <comment>pyproject.toml</> file in the current directory."
     )
 
-    options = [
+    options: ClassVar[list[Option]] = [
         option("name", None, "Name of the package.", flag=False),
         option("description", None, "Description of the package.", flag=False),
         option("author", None, "Author name of the package.", flag=False),
@@ -69,30 +73,39 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
     def handle(self) -> int:
         from pathlib import Path
 
+        project_path = Path.cwd()
+
+        if self.io.input.option("project"):
+            project_path = Path(self.io.input.option("project"))
+            if not project_path.exists() or not project_path.is_dir():
+                self.line_error("<error>The --project path is not a directory.</error>")
+                return 1
+
+        return self._init_pyproject(project_path=project_path)
+
+    def _init_pyproject(
+        self,
+        project_path: Path,
+        allow_interactive: bool = True,
+        layout_name: str = "standard",
+        readme_format: str = "md",
+        allow_layout_creation_on_empty: bool = False,
+    ) -> int:
         from poetry.core.vcs.git import GitConfig
 
         from poetry.config.config import Config
         from poetry.layouts import layout
         from poetry.pyproject.toml import PyProjectTOML
-        from poetry.utils.env import EnvManager
 
-        project_path = Path.cwd()
-
-        if self.io.input.option("directory"):
-            project_path = Path(self.io.input.option("directory"))
-            if not project_path.exists() or not project_path.is_dir():
-                self.line_error(
-                    "<error>The --directory path is not a directory.</error>"
-                )
-                return 1
+        is_interactive = self.io.is_interactive() and allow_interactive
 
         pyproject = PyProjectTOML(project_path / "pyproject.toml")
 
         if pyproject.file.exists():
             if pyproject.is_poetry_project():
                 self.line_error(
-                    "<error>A pyproject.toml file with a poetry section already"
-                    " exists.</error>"
+                    "<error>A pyproject.toml file with a project and/or"
+                    " a poetry section already exists.</error>"
                 )
                 return 1
 
@@ -105,7 +118,7 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
 
         vcs_config = GitConfig()
 
-        if self.io.is_interactive():
+        if is_interactive:
             self.line("")
             self.line(
                 "This command will guide you through creating your"
@@ -115,21 +128,24 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
 
         name = self.option("name")
         if not name:
-            name = Path.cwd().name.lower()
+            name = project_path.name.lower()
 
-            question = self.create_question(
-                f"Package name [<comment>{name}</comment>]: ", default=name
-            )
-            name = self.ask(question)
+            if is_interactive:
+                question = self.create_question(
+                    f"Package name [<comment>{name}</comment>]: ", default=name
+                )
+                name = self.ask(question)
 
         version = "0.1.0"
-        question = self.create_question(
-            f"Version [<comment>{version}</comment>]: ", default=version
-        )
-        version = self.ask(question)
 
-        description = self.option("description")
-        if not description:
+        if is_interactive:
+            question = self.create_question(
+                f"Version [<comment>{version}</comment>]: ", default=version
+            )
+            version = self.ask(question)
+
+        description = self.option("description") or ""
+        if not description and is_interactive:
             description = self.ask(self.create_question("Description []: ", default=""))
 
         author = self.option("author")
@@ -139,37 +155,35 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
             if author_email:
                 author += f" <{author_email}>"
 
-        question = self.create_question(
-            f"Author [<comment>{author}</comment>, n to skip]: ", default=author
-        )
-        question.set_validator(lambda v: self._validate_author(v, author))
-        author = self.ask(question)
+        if is_interactive:
+            question = self.create_question(
+                f"Author [<comment>{author}</comment>, n to skip]: ", default=author
+            )
+            question.set_validator(lambda v: self._validate_author(v, author))
+            author = self.ask(question)
 
         authors = [author] if author else []
 
-        license = self.option("license")
-        if not license:
-            license = self.ask(self.create_question("License []: ", default=""))
+        license_name = self.option("license")
+        if not license_name and is_interactive:
+            license_name = self.ask(self.create_question("License []: ", default=""))
 
         python = self.option("python")
         if not python:
             config = Config.create()
-            default_python = (
-                "^"
-                + EnvManager.get_python_version(
-                    precision=2,
-                    prefer_active_python=config.get("virtualenvs.prefer-active-python"),
-                    io=self.io,
-                ).to_string()
+            python = (
+                ">="
+                + Python.get_preferred_python(config, self.io).minor_version.to_string()
             )
 
-            question = self.create_question(
-                f"Compatible Python versions [<comment>{default_python}</comment>]: ",
-                default=default_python,
-            )
-            python = self.ask(question)
+            if is_interactive:
+                question = self.create_question(
+                    f"Compatible Python versions [<comment>{python}</comment>]: ",
+                    default=python,
+                )
+                python = self.ask(question)
 
-        if self.io.is_interactive():
+        if is_interactive:
             self.line("")
 
         requirements: Requirements = {}
@@ -180,27 +194,25 @@ The <c1>init</c1> command creates a basic <comment>pyproject.toml</> file in the
 
         question_text = "Would you like to define your main dependencies interactively?"
         help_message = """\
-You can specify a package in the following forms:
-  - A single name (<b>requests</b>): this will search for matches on PyPI
-  - A name and a constraint (<b>requests@^2.23.0</b>)
-  - A git url (<b>git+https://github.com/python-poetry/poetry.git</b>)
-  - A git url with a revision\
- (<b>git+https://github.com/python-poetry/poetry.git#develop</b>)
-  - A file path (<b>../my-package/my-package.whl</b>)
-  - A directory (<b>../my-package/</b>)
-  - A url (<b>https://example.com/packages/my-package-0.1.0.tar.gz</b>)
-"""
+        You can specify a package in the following forms:
+          - A single name (<b>requests</b>): this will search for matches on PyPI
+          - A name and a constraint (<b>requests@^2.23.0</b>)
+          - A git url (<b>git+https://github.com/python-poetry/poetry.git</b>)
+          - A git url with a revision\
+         (<b>git+https://github.com/python-poetry/poetry.git#develop</b>)
+          - A file path (<b>../my-package/my-package.whl</b>)
+          - A directory (<b>../my-package/</b>)
+          - A url (<b>https://example.com/packages/my-package-0.1.0.tar.gz</b>)
+        """
 
         help_displayed = False
-        if self.confirm(question_text, True):
-            if self.io.is_interactive():
-                self.line(help_message)
-                help_displayed = True
+        if is_interactive and self.confirm(question_text, True):
+            self.line(help_message)
+            help_displayed = True
             requirements.update(
                 self._format_requirements(self._determine_requirements([]))
             )
-            if self.io.is_interactive():
-                self.line("")
+            self.line("")
 
         dev_requirements: Requirements = {}
         if self.option("dev-dependency"):
@@ -211,44 +223,63 @@ You can specify a package in the following forms:
         question_text = (
             "Would you like to define your development dependencies interactively?"
         )
-        if self.confirm(question_text, True):
-            if self.io.is_interactive() and not help_displayed:
+        if is_interactive and self.confirm(question_text, True):
+            if not help_displayed:
                 self.line(help_message)
 
             dev_requirements.update(
                 self._format_requirements(self._determine_requirements([]))
             )
-            if self.io.is_interactive():
-                self.line("")
 
-        layout_ = layout("standard")(
+            self.line("")
+
+        layout_ = layout(layout_name)(
             name,
             version,
             description=description,
             author=authors[0] if authors else None,
-            license=license,
+            readme_format=readme_format,
+            license=license_name,
             python=python,
             dependencies=requirements,
             dev_dependencies=dev_requirements,
         )
 
-        content = layout_.generate_poetry_content()
+        create_layout = not project_path.exists() or (
+            allow_layout_creation_on_empty and not any(project_path.iterdir())
+        )
+
+        if create_layout:
+            layout_.create(project_path, with_pyproject=False)
+
+        content = layout_.generate_project_content(project_path)
         for section, item in content.items():
             pyproject.data.append(section, item)
 
-        if self.io.is_interactive():
+        if is_interactive:
             self.line("<info>Generated file</info>")
             self.line("")
             self.line(pyproject.data.as_string().replace("\r\n", "\n"))
             self.line("")
 
-        if not self.confirm("Do you confirm generation?", True):
+        if is_interactive and not self.confirm("Do you confirm generation?", True):
             self.line_error("<error>Command aborted</error>")
 
             return 1
 
         pyproject.save()
 
+        if create_layout:
+            path = project_path.resolve()
+
+            with suppress(ValueError):
+                path = path.relative_to(Path.cwd())
+
+            self.line(
+                f"Created package <info>{layout_._package_name}</> in"
+                f" <fg=blue>{path.as_posix()}</>"
+            )
+
         return 0
 
     def _generate_choice_list(
@@ -274,9 +305,13 @@ You can specify a package in the following forms:
     def _determine_requirements(
         self,
         requires: list[str],
-        allow_prereleases: bool = False,
+        allow_prereleases: bool | None = None,
         source: str | None = None,
+        is_interactive: bool | None = None,
     ) -> list[dict[str, Any]]:
+        if is_interactive is None:
+            is_interactive = self.io.is_interactive()
+
         if not requires:
             result = []
 
@@ -366,7 +401,7 @@ You can specify a package in the following forms:
                 if package:
                     result.append(constraint)
 
-                if self.io.is_interactive():
+                if is_interactive:
                     package = self.ask(follow_up_question)
 
             return result
@@ -407,7 +442,7 @@ You can specify a package in the following forms:
         self,
         name: str,
         required_version: str | None = None,
-        allow_prereleases: bool = False,
+        allow_prereleases: bool | None = None,
         source: str | None = None,
     ) -> tuple[str, str]:
         from poetry.version.version_selector import VersionSelector
@@ -421,15 +456,16 @@ You can specify a package in the following forms:
             # TODO: find similar
             raise ValueError(f"Could not find a matching version of package {name}")
 
-        return package.pretty_name, f"^{package.version.to_string()}"
+        version = package.version.without_local()
+        return package.pretty_name, f"^{version.to_string()}"
 
     def _parse_requirements(self, requirements: list[str]) -> list[dict[str, Any]]:
-        from poetry.core.pyproject.exceptions import PyProjectException
+        from poetry.core.pyproject.exceptions import PyProjectError
 
         try:
             cwd = self.poetry.file.path.parent
             artifact_cache = self.poetry.pool.artifact_cache
-        except (PyProjectException, RuntimeError):
+        except (PyProjectError, RuntimeError):
             cwd = Path.cwd()
             artifact_cache = self._get_pool().artifact_cache
 
@@ -438,7 +474,10 @@ You can specify a package in the following forms:
             env=self.env if isinstance(self, EnvCommand) else None,
             cwd=cwd,
         )
-        return [parser.parse(requirement) for requirement in requirements]
+        return [
+            parser.parse(re.sub(r"@\s*latest$", "", requirement, flags=re.I))
+            for requirement in requirements
+        ]
 
     def _format_requirements(self, requirements: list[dict[str, str]]) -> Requirements:
         requires: Requirements = {}
@@ -456,10 +495,12 @@ You can specify a package in the following forms:
 
         return requires
 
-    def _validate_author(self, author: str, default: str) -> str | None:
-        from poetry.core.packages.package import AUTHOR_REGEX
+    @staticmethod
+    def _validate_author(author: str, default: str) -> str | None:
+        from poetry.core.utils.helpers import combine_unicode
+        from poetry.core.utils.patterns import AUTHOR_REGEX
 
-        author = author or default
+        author = combine_unicode(author or default)
 
         if author in ["n", "no"]:
             return None
@@ -481,6 +522,7 @@ You can specify a package in the following forms:
         return package
 
     def _get_pool(self) -> RepositoryPool:
+        from poetry.config.config import Config
         from poetry.repositories import RepositoryPool
         from poetry.repositories.pypi_repository import PyPiRepository
 
@@ -489,6 +531,7 @@ You can specify a package in the following forms:
 
         if self._pool is None:
             self._pool = RepositoryPool()
-            self._pool.add_repository(PyPiRepository())
+            pool_size = Config.create().installer_max_workers
+            self._pool.add_repository(PyPiRepository(pool_size=pool_size))
 
         return self._pool
