@@ -2,13 +2,11 @@ from __future__ import annotations
 
 import os
 import shutil
-import subprocess
 import sys
 import textwrap
 
 from pathlib import Path
 from typing import TYPE_CHECKING
-from typing import Any
 
 import pytest
 
@@ -24,6 +22,7 @@ from tests.helpers import get_package
 
 if TYPE_CHECKING:
     from collections.abc import Iterator
+    from unittest.mock import MagicMock
 
     from poetry.core.packages.package import Package
     from pytest import FixtureRequest
@@ -34,6 +33,7 @@ if TYPE_CHECKING:
     from tests.helpers import PoetryTestApplication
     from tests.helpers import TestRepository
     from tests.types import FixtureDirGetter
+    from tests.types import MockedPythonRegister
 
 
 @pytest.fixture
@@ -62,10 +62,10 @@ def tester(patches: None) -> CommandTester:
 
 
 def test_basic_interactive(
-    tester: CommandTester, init_basic_inputs: str, init_basic_toml: str
+    tester: CommandTester, init_basic_inputs: str, init_basic_toml_no_readme: str
 ) -> None:
     tester.execute(inputs=init_basic_inputs)
-    assert init_basic_toml in tester.io.fetch_output()
+    assert init_basic_toml_no_readme in tester.io.fetch_output()
 
 
 def test_noninteractive(
@@ -146,17 +146,17 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "pendulum (>=2.0.0,<3.0.0)",
     "flask (>=2.0.0,<3.0.0)"
 ]
 
-[tool.poetry]
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
 
 [build-system]
 requires = ["poetry-core>=2.0.0,<3.0.0"]
@@ -202,7 +202,6 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 """
 
@@ -232,7 +231,6 @@ description = ""
 authors = [
     {{name = "Your Name",email = "you@example.com"}}
 ]
-readme = "README.md"
 requires-python = ">={python}"
 """
     assert expected in tester.io.fetch_output()
@@ -272,16 +270,15 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "demo @ git+https://github.com/demo/demo.git"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -368,16 +365,15 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "demo @ git+https://github.com/demo/demo.git@develop"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -417,16 +413,15 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "demo @ git+https://github.com/demo/pyproject-demo.git"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -473,16 +468,15 @@ authors = [
     {{name = "Your Name",email = "you@example.com"}}
 ]
 license = {{text = "MIT"}}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "demo @ {demo_uri}"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
     assert expected in tester.io.fetch_output()
 
@@ -528,16 +522,15 @@ authors = [
     {{name = "Your Name",email = "you@example.com"}}
 ]
 license = {{text = "MIT"}}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "demo @ {demo_uri}"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -584,16 +577,15 @@ authors = [
     {{name = "Your Name",email = "you@example.com"}}
 ]
 license = {{text = "MIT"}}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "demo @ {demo_uri}"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -632,17 +624,16 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.8"
 dependencies = [
     "foo (==1.19.2)",
     "pendulum (>=2.0.0,<3.0.0)"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (==3.6.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -670,7 +661,6 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 """
 
@@ -702,7 +692,6 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "pendulum (>=2.0.0,<3.0.0)"
@@ -745,7 +734,6 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "pendulum (>=2.0.0,<3.0.0)",
@@ -781,15 +769,14 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     assert expected in tester.io.fetch_output()
@@ -828,22 +815,19 @@ authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
-pytest-requests = "^0.2.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)",
+    "pytest-requests (>=0.2.0,<0.3.0)"
+]
 """
 
     output = tester.io.fetch_output()
     assert expected in output
-    assert 'pytest-requests = "^0.2.0"' in output
-    assert 'pytest = "^3.6.0"' in output
 
 
 def test_predefined_all_options(tester: CommandTester, repo: TestRepository) -> None:
@@ -878,16 +862,15 @@ authors = [
     {name = "Foo Bar",email = "foo@example.com"}
 ]
 license = {text = "MIT"}
-readme = "README.md"
 requires-python = ">=3.8"
 dependencies = [
     "pendulum (>=2.0.0,<3.0.0)"
 ]
 
-[tool.poetry]
-
-[tool.poetry.group.dev.dependencies]
-pytest = "^3.6.0"
+[dependency-groups]
+dev = [
+    "pytest (>=3.6.0,<4.0.0)"
+]
 """
 
     output = tester.io.fetch_output()
@@ -909,7 +892,7 @@ def test_init_existing_pyproject_simple(
     tester: CommandTester,
     source_dir: Path,
     init_basic_inputs: str,
-    init_basic_toml: str,
+    init_basic_toml_no_readme: str,
 ) -> None:
     pyproject_file = source_dir / "pyproject.toml"
     existing_section = """
@@ -918,8 +901,9 @@ line-length = 88
 """
     pyproject_file.write_text(existing_section, encoding="utf-8")
     tester.execute(inputs=init_basic_inputs)
-    assert f"{existing_section}\n{init_basic_toml}" in pyproject_file.read_text(
-        encoding="utf-8"
+    assert (
+        f"{existing_section}\n{init_basic_toml_no_readme}"
+        in pyproject_file.read_text(encoding="utf-8")
     )
 
 
@@ -928,7 +912,7 @@ def test_init_existing_pyproject_consistent_linesep(
     tester: CommandTester,
     source_dir: Path,
     init_basic_inputs: str,
-    init_basic_toml: str,
+    init_basic_toml_no_readme: str,
     linesep: str,
 ) -> None:
     pyproject_file = source_dir / "pyproject.toml"
@@ -941,7 +925,7 @@ line-length = 88
     tester.execute(inputs=init_basic_inputs)
     with open(pyproject_file, newline="", encoding="utf-8") as f:
         content = f.read()
-    init_basic_toml = init_basic_toml.replace("\n", linesep)
+    init_basic_toml = init_basic_toml_no_readme.replace("\n", linesep)
     assert f"{existing_section}{linesep}{init_basic_toml}" in content
 
 
@@ -976,7 +960,6 @@ description = ""
 authors = [
     {name = "Your Name",email = "you@example.com"}
 ]
-readme = "README.md"
 requires-python = ">=3.6"
 dependencies = [
     "foo (>=1.19.2,<2.0.0)"
@@ -1087,13 +1070,12 @@ def test_package_include(
         f'name = "{package_name.replace(".", "-")}"\n'  # canonicalized
         'version = "0.1.0"\n'
         'description = ""\n'
-        'authors = [\n'
+        "authors = [\n"
         '    {name = "poetry"}\n'
-        ']\n'
-        'readme = "README.md"\n'
+        "]\n"
         'requires-python = ">=3.10"\n'
-        'dependencies = [\n'
-        ']\n'
+        "dependencies = [\n"
+        "]\n"
         f"{packages}"  # This line is optional. Thus, no newline here.
     )
     assert expected in tester.io.fetch_output()
@@ -1110,26 +1092,12 @@ def test_respect_use_poetry_python_on_init(
     use_poetry_python: bool,
     python: str,
     config: Config,
-    mocker: MockerFixture,
     tester: CommandTester,
     source_dir: Path,
+    mocked_python_register: MockedPythonRegister,
+    with_no_active_python: MagicMock,
 ) -> None:
-    from poetry.utils.env import GET_PYTHON_VERSION_ONELINER
-
-    orig_check_output = subprocess.check_output
-
-    def mock_check_output(cmd: str, *_: Any, **__: Any) -> str:
-        if GET_PYTHON_VERSION_ONELINER in cmd:
-            return "1.1.1"
-
-        result: str = orig_check_output(cmd, *_, **__)
-        return result
-
-    mocker.patch("subprocess.check_output", side_effect=mock_check_output)
-    mocker.patch(
-        "poetry.utils.env.python_manager.Python._full_python_path",
-        return_value=Path(f"/usr/bin/python{python}"),
-    )
+    mocked_python_register(f"{python}.1", make_system=True)
     config.config["virtualenvs"]["use-poetry-python"] = use_poetry_python
     pyproject_file = source_dir / "pyproject.toml"
 
@@ -1157,3 +1125,93 @@ def test_get_pool(mocker: MockerFixture, source_dir: Path) -> None:
     assert isinstance(command, InitCommand)
     pool = command._get_pool()
     assert pool.repositories
+
+
+def test_init_does_not_create_project_structure_in_empty_directory(
+    tester: CommandTester, source_dir: Path
+) -> None:
+    """Test that poetry init does not create project structure in empty directory."""
+    inputs = [
+        "my-package",  # Package name
+        "1.0.0",  # Version
+        "",  # Description
+        "n",  # Author
+        "",  # License
+        "",  # Python
+        "n",  # Interactive packages
+        "n",  # Interactive dev packages
+        "\n",  # Generate
+    ]
+
+    tester.execute(inputs="\n".join(inputs))
+
+    # Should only create pyproject.toml
+    assert (source_dir / "pyproject.toml").exists()
+
+    # Should NOT create these
+    assert not (source_dir / "tests").exists()
+    assert not (source_dir / "my_package").exists()
+    assert not (source_dir / "src").exists()
+    assert not (source_dir / "README.md").exists()
+
+
+def test_init_does_not_create_project_structure_in_non_empty_directory(
+    tester: CommandTester, source_dir: Path
+) -> None:
+    """Test that poetry init does not create project structure in non-empty directory."""
+    # Create some existing files
+    (source_dir / "existing_file.txt").write_text("existing content", encoding="utf-8")
+    (source_dir / "existing_dir").mkdir()
+
+    inputs = [
+        "my-package",  # Package name
+        "1.0.0",  # Version
+        "",  # Description
+        "n",  # Author
+        "",  # License
+        "",  # Python
+        "n",  # Interactive packages
+        "n",  # Interactive dev packages
+        "\n",  # Generate
+    ]
+
+    tester.execute(inputs="\n".join(inputs))
+
+    # Should only create pyproject.toml
+    assert (source_dir / "pyproject.toml").exists()
+
+    # Should NOT create these
+    assert not (source_dir / "tests").exists()
+    assert not (source_dir / "my_package").exists()
+    assert not (source_dir / "src").exists()
+    assert not (source_dir / "README.md").exists()
+
+    # Existing files should remain
+    assert (source_dir / "existing_file.txt").exists()
+    assert (source_dir / "existing_dir").exists()
+
+
+def test_init_adds_readme_key_when_readme_exists(
+    tester: CommandTester, tmp_path: Path
+) -> None:
+    # Arrange: ensure README.md exists
+    readme = tmp_path / "README.md"
+    readme.write_text("# My Project\n", encoding="utf-8")
+    # Act
+    tester.execute(interactive=False)
+    # Assert
+    pyproject = (tmp_path / "pyproject.toml").read_text(encoding="utf-8")
+    assert 'readme = "README.md"' in pyproject
+
+
+def test_init_does_not_add_readme_key_when_readme_missing(
+    tester: CommandTester, tmp_path: Path
+) -> None:
+    # Arrange: ensure README.md does NOT exist
+    readme = tmp_path / "README.md"
+    assert not readme.exists()
+    # Act
+    tester.execute(interactive=False)
+    # Assert
+    pyproject = (tmp_path / "pyproject.toml").read_text(encoding="utf-8")
+    assert "readme =" not in pyproject
