@@ -4,18 +4,16 @@ import shutil
 
 from pathlib import Path
 from typing import TYPE_CHECKING
-from typing import Any
+from typing import NoReturn
 
 import pytest
 import requests
+import responses
 
 from poetry.factory import Factory
-from poetry.publishing.uploader import UploadError
 
 
 if TYPE_CHECKING:
-    import httpretty
-
     from cleo.testers.application_tester import ApplicationTester
     from pytest_mock import MockerFixture
 
@@ -44,11 +42,9 @@ def test_publish_not_possible_in_non_package_mode(
 def test_publish_returns_non_zero_code_for_upload_errors(
     app: PoetryTestApplication,
     app_tester: ApplicationTester,
-    http: type[httpretty.httpretty],
+    http: responses.RequestsMock,
 ) -> None:
-    http.register_uri(
-        http.POST, "https://upload.pypi.org/legacy/", status=400, body="Bad Request"
-    )
+    http.post("https://upload.pypi.org/legacy/", status=400, body="Bad Request")
 
     exit_code = app_tester.execute("publish --username foo --password bar")
 
@@ -69,22 +65,20 @@ HTTP Error 400: Bad Request | b'Bad Request'
 def test_publish_returns_non_zero_code_for_connection_errors(
     app: PoetryTestApplication,
     app_tester: ApplicationTester,
-    http: type[httpretty.httpretty],
+    http: responses.RequestsMock,
 ) -> None:
-    def request_callback(*_: Any, **__: Any) -> None:
-        raise requests.ConnectionError()
+    def request_callback(request: requests.PreparedRequest) -> NoReturn:
+        raise requests.ConnectionError
 
-    http.register_uri(
-        http.POST, "https://upload.pypi.org/legacy/", body=request_callback
+    http.add_callback(
+        responses.POST, "https://upload.pypi.org/legacy/", callback=request_callback
     )
 
     exit_code = app_tester.execute("publish --username foo --password bar")
 
     assert exit_code == 1
 
-    expected = str(UploadError(error=requests.ConnectionError()))
-
-    assert expected in app_tester.io.fetch_error()
+    assert "Error connecting to repository" in app_tester.io.fetch_error()
 
 
 def test_publish_with_cert(
@@ -119,11 +113,9 @@ def test_publish_with_client_cert(
     ],
 )
 def test_publish_dry_run_skip_existing(
-    app_tester: ApplicationTester, http: type[httpretty.httpretty], options: str
+    app_tester: ApplicationTester, http: responses.RequestsMock, options: str
 ) -> None:
-    http.register_uri(
-        http.POST, "https://upload.pypi.org/legacy/", status=409, body="Conflict"
-    )
+    http.post("https://upload.pypi.org/legacy/", status=409, body="Conflict")
 
     exit_code = app_tester.execute(f"publish {options} --username foo --password bar")
 
@@ -138,11 +130,9 @@ def test_publish_dry_run_skip_existing(
 
 
 def test_skip_existing_output(
-    app_tester: ApplicationTester, http: type[httpretty.httpretty]
+    app_tester: ApplicationTester, http: responses.RequestsMock
 ) -> None:
-    http.register_uri(
-        http.POST, "https://upload.pypi.org/legacy/", status=409, body="Conflict"
-    )
+    http.post("https://upload.pypi.org/legacy/", status=409, body="Conflict")
 
     exit_code = app_tester.execute(
         "publish --skip-existing --username foo --password bar"
@@ -156,7 +146,7 @@ def test_skip_existing_output(
 
 @pytest.mark.parametrize("dist_dir", [None, "dist", "other_dist/dist", "absolute"])
 def test_publish_dist_dir_option(
-    http: type[httpretty.httpretty],
+    http: responses.RequestsMock,
     fixture_dir: FixtureDirGetter,
     tmp_path: Path,
     tmp_venv: VirtualEnv,
@@ -167,9 +157,7 @@ def test_publish_dist_dir_option(
     target_dir = tmp_path / "project"
     shutil.copytree(str(source_dir), str(target_dir))
 
-    http.register_uri(
-        http.POST, "https://upload.pypi.org/legacy/", status=409, body="Conflict"
-    )
+    http.post("https://upload.pypi.org/legacy/", status=409, body="Conflict")
 
     poetry = Factory().create_poetry(target_dir)
     tester = command_tester_factory("publish", poetry, environment=tmp_venv)
@@ -193,7 +181,7 @@ def test_publish_dist_dir_option(
 
 @pytest.mark.parametrize("dist_dir", ["../dist", "tmp/dist", "absolute"])
 def test_publish_dist_dir_and_build_options(
-    http: type[httpretty.httpretty],
+    http: responses.RequestsMock,
     fixture_dir: FixtureDirGetter,
     tmp_path: Path,
     tmp_venv: VirtualEnv,
@@ -207,9 +195,7 @@ def test_publish_dist_dir_and_build_options(
     # Remove dist dir because as it will be built again
     shutil.rmtree(target_dir / "dist")
 
-    http.register_uri(
-        http.POST, "https://upload.pypi.org/legacy/", status=409, body="Conflict"
-    )
+    http.post("https://upload.pypi.org/legacy/", status=409, body="Conflict")
 
     poetry = Factory().create_poetry(target_dir)
     tester = command_tester_factory("publish", poetry, environment=tmp_venv)
