@@ -109,6 +109,34 @@ def release_info() -> PackageInfo:
     )
 
 
+@pytest.fixture
+def release_info_complete() -> PackageInfo:
+    return PackageInfo(
+        name="mylib",
+        version="1.0",
+        summary="",
+        requires_dist=[],
+        requires_python=">=3.9",
+        files=[
+            {
+                "file": "mylib-1.0-py3-none-any.whl",
+                "hash": "sha256:dummyhashvalue1234567890abcdef",
+                "url": "https://example.org/mylib-1.0-py3-none-any.whl",
+                "size": 12345,
+                "upload_time": "2024-01-01T12:00:00Z",
+            },
+            {
+                "file": "mylib-1.0.tar.gz",
+                "hash": "sha256:anotherdummyhashvalueabcdef1234567890",
+                "url": "https://example.org/mylib-1.0.tar.gz",
+                "size": 12346,
+                "upload_time": "2024-01-01T12:00:01Z",
+            },
+        ],
+        cache_version=str(CachedRepository.CACHE_VERSION),
+    )
+
+
 @pytest.fixture
 def outdated_release_info() -> PackageInfo:
     return PackageInfo(
@@ -976,6 +1004,38 @@ def test_complete_package_outdated_cache(
     assert pool_refresh_spy.call_count == 1
 
 
+def test_complete_package_no_refresh_on_url_size_upload_info(
+    root: ProjectPackage,
+    release_info: PackageInfo,
+    release_info_complete: PackageInfo,
+    mocker: MockerFixture,
+) -> None:
+    repo = MockCachedRepository("repo")
+    pool = RepositoryPool()
+    pool.add_repository(repo)
+    provider = Provider(root, pool, NullIO())
+    pool_refresh_spy = mocker.spy(provider.pool, "refresh")
+
+    assert release_info.name is not None
+    assert release_info.version is not None
+    package = Package(release_info.name, release_info.version)
+    package.files = release_info.files  # up-to-date files from lock
+    assert "url" not in package.files[0]
+
+    # trigger caching complete info
+    repo._get_release_info = lambda name, version: release_info_complete.asdict()  # type: ignore[method-assign]
+    assert len(repo.package(package.name, package.version).files) == 2
+
+    # Only additional information in cache, names and hashes from lock file are the same
+    # -> no refresh needed
+    complete_package = provider.complete_package(
+        DependencyPackage(package.to_dependency(), package)
+    )
+    assert len(complete_package.package.files) == 2
+    assert "url" in complete_package.package.files[0]
+    assert pool_refresh_spy.call_count == 0
+
+
 def test_source_dependency_is_satisfied_by_direct_origin(
     provider: Provider, repository: Repository
 ) -> None:
